#!/bin/bash
#
# source: http://www.mirrorservice.org/sites/download.sourceforge.net/pub/sourceforge/p/project/pc/pcmanfm/PCManFM2 + Libfm (experimental)/libfm (required by PCManFM)/libfm-0.1.14.tar.gz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft="libfm"
softversion="0.1.14"
arch="i486"
cpu="i686"
packageversion="70.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
  \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
  -exec chmod 755 {} \; -o \
  \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
  -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --with-html-dir=/usr/doc/$soft-$softversion

make -j4 
make install DESTDIR=$dest

find $dest | xargs file | grep -e "executable" -e "shared object" \
  | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

#-------------------Prepare the documentation:

cp -a AUTHORS COPYING README TODO $dest/usr/doc/$soft-$softversion

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler------------------------------------------------------|
libfm: libfm - provides file management functions
libfm:
libfm: LibFM provides file management functions built on top of Glib/GIO,
libfm: giving a convenient higher-level API.
libfm: 
libfm: 
libfm: 
libfm: 
libfm:
libfm:
libfm:
EODESC


mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5